/**
* conffile.h - Routines/Structures for parsing configuration files
* and command line arguments
*
* Copyright (C) 2004-2005 Pantelis Frangoudis, Elias Efstathiou
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef _PWNC_CONF_H
#define _PWNC_CONF_H

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>

#define VTYPE_INT 0
#define VTYPE_STRING 1
#define VTYPE_NOVAL 2

//this struct represents a conf file entry, that is a variable-value pair
//var_name: name of variable as this appears in the conf file
//vtype: integer or string value
//var: the address of the variable that will store the correspondent conf file var
typedef struct conf_entry_t {
	unsigned char var_name[20];
	unsigned short vtype;
	void *var;
} CENTRY;

typedef struct cmd_arg_t {
	unsigned char full_name[20];
	unsigned char swtch[20];
	unsigned short vtype;
	void *var;
} CMD_ARG;

CMD_ARG *get_arg_by_name(unsigned char *name, CMD_ARG *args, int num_args);
CMD_ARG *get_arg_by_switch(unsigned char *swtch, CMD_ARG *args, int num_args);
CMD_ARG *make_valid_args(unsigned char *arg_names[], unsigned char *switches[], void **vars, unsigned short *vtypes, int argnum);
void parse_cmd_line_args(int argc, char **argv, CMD_ARG *args, int num_args);

CENTRY *get_entry_by_name(unsigned char *name, CENTRY *entries, int num_entries);
CENTRY *make_valid_entries(unsigned char *var_names[], void **vars, unsigned short *vtypes, int varnum);
int parse_line(unsigned char *line, unsigned char *key, unsigned char *value);
void parse_conf_file(CENTRY *entries, int entry_num, FILE *fp);

#endif /* _PWNC_CONF_H */
